# 接入 302.AI

302.AI 是企业级 AI 应用平台，支持快捷接入全球各类 AI 模型。

## 使用

点击[此链接](https://share.302.ai/rr1M3l) 注册账户。

注册完毕之后，点击[此链接](https://302.ai/apis/)选择需要接入的模型。

根据需求，进入[此链接](https://dash.302.ai/charge) 充值对应的金额。

## 接入

打开 AstrBot 控制台 -> 服务提供商页面，点击新增提供商，找到并点击 `302.AI`(需要版本 >= 3.5.18)

修改 ID，并将 API Key 和模型名称填入对话框表单，点击保存，即可完成创建。

## 使用

对机器人输入 `/provider` 指令，将提供商切换到刚刚添加的 302.AI 提供商，即可使用。
